<?php

require_once("fakemail/fakemail.php"); # in CVS for http://sf.net/projects/fakemail
require_once("Mail/mimeDecode.php"); # PEAR library
require_once("fakemail/simplemailmessage.php");

/**
	SimpleMail
	Gives a simple simulation of an email-reader
	- 'log in' to specify your email addres
	- 'loadMessages' to load all your messages and MIME-decode them
	- 'getLatestByTitle' to find a message with a given title
	- 'getLatestFromSender' to get the latest email with a given string in the sender
	- 'getMessageByNumber' to get a particular message
	- 'getMailCount' to get the number of emails
	
	Requires a running instance of fakemail to be passed to it when created.
	
*/

class SimpleMail{
	
	var $_fakemail;
	
	var $recipient;
	
	var $mails;
	
	var $mimedecodeparams;
	
	function SimpleMail(&$fakemail){
		if(!is_a($fakemail,"FakeMailDaemon")){
			trigger_error ("You must pass a valid FakeMailDaemon when initialising SimpleMail", E_USER_ERROR);
		}
		$this->_fakemail =& $fakemail;
		
		$this->mimedecodeparams=array();
		$this->mimedecodeparams['include_bodies'] = TRUE;
		$this->mimedecodeparams['decode_bodies']  = TRUE;
		$this->mimedecodeparams['decode_headers'] = TRUE;
	}
	
	function login($email){
		//print("Setting recipient to $email<br>\n");
		$this->recipient=$email;
	}
	
	function loadMessages(){
		//print("Loading messages for ".$this->recipient."<br>\n");
		
		if(!isset($this->recipient)){
			trigger_error("SimpleMail: use login() before getMessages()!", E_USER_ERROR);
		}
		
		$rawmails=array();
		
		$rawmails =& $this->_fakemail->getRecipientMailContents($this->recipient);
		
		//print("There were ".count($rawmails)." raw emails found<br>\n");
		for($i=0;$i<count($rawmails);$i++){

			$this->mails[] = new SimpleMailMessage($rawmails[$i]);
			
			/*
			if(!$this->mails[count($this->mails)-1]->decode()){
				die("Couldn't decode message: ".$this->mails[count($this->mails)-1]->error);
			}
			print("MIME-decoded email $i<br>\n");
			*/
		}
		
		return true;
	}
	
	function getMailCount(){
		return count($this->mails);
	}
	
	function &getMessageByNumber($num){
		if($num<0 || $num >= count($mails) || floor($num)!==$num){
			trigger_error("SimpleMail: invalid email number $num", E_USER_ERROR);
		}
		
		return $this->mails[$num];
	}
	
	/**
		Pass a PCRE to this method and it will return the last
		mail that contains the regexp in the Subject: header
	*/
	function &getLatestBySubject($subjectpattern){
		//print("There are ".count($this->mails)." mails<br>\n");
		
		for($i=count($this->mails)-1;$i>=0;$i--){
			//print("Checking subject of message $i...<br>\n");
			$subject=$this->mails[$i]->getSubject();
			//print("Subject header is $subject<br>\n");
			
			if(preg_match($subjectpattern,$subject)){
				//print("MATCH! :)<br>\n");
				return $this->mails[$i];
			}
			
			//print("No match, continuing back in list<br>\n");
		}
		//print("None found<br>\n");
		return false;
	}
	
	/**
		Pass a PCRE to this method and it will return the last
		mail that contains the regexp in the Sender: header
	*/
	function &getLatestBySender($frompattern){
		for($i=count($this->mails)-1;$i>=0;$i--){
			$from = $this->mails[$i]->getFrom();
			
			if(preg_match($frompattern,$from)){
				return $this->mails[$i];
			}
		}
		return false;
	}
}

?>